@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document::OpenAPI;
 # ABSTRACT: One OpenAPI v3.1 or v3.2 document
 # KEYWORDS: JSON Schema data validation request response OpenAPI
 
-our $VERSION = '0.109';
+our $VERSION = '0.110';
 
 use 5.020;
 use utf8;
@@ -235,7 +235,6 @@ sub traverse ($self, $evaluator, $config_override = {}) {
   my $result = $evaluator->evaluate(
     $schema, $self->metaschema_uri,
     {
-      short_circuit => 1,
       collect_annotations => 0,
       validate_formats => 1,
       callbacks => {
@@ -286,7 +285,7 @@ sub traverse ($self, $evaluator, $config_override = {}) {
 
   if (not $result->valid) {
     foreach my $e ($result->errors) {
-      if ($e->keyword eq 'not'
+      if (($e->keyword//'') eq 'not'
           and $e->absolute_keyword_location->fragment eq '/$defs/parameters/not'
           and $e->absolute_keyword_location->clone->fragment(undef) eq DEFAULT_METASCHEMA->{$self->oas_version}
       ) {
@@ -578,7 +577,7 @@ JSON::Schema::Modern::Document::OpenAPI - One OpenAPI v3.1 or v3.2 document
 
 =head1 VERSION
 
-version 0.109
+version 0.110
 
 =head1 SYNOPSIS
 
@@ -587,24 +586,23 @@ version 0.109
   my $openapi_document = JSON::Schema::Modern::Document::OpenAPI->new(
     canonical_uri => 'https://example.com/v1/api',
     schema => decode_json(<<JSON),
-{
-  "openapi": "3.2.0",
-  "info": {
-    "title": "my title",
-    "version": "1.2.3"
-  },
-  "components": {
-  },
-  "paths": {
-    "/foo": {
-      "get": {}
+  {
+    "openapi": "3.2.0",
+    "$self": "openapi.json",
+    "info": {
+      "title": "my title",
+      "version": "1.2.3"
     },
-    "/foo/{foo_id}": {
-      "post": {}
+    "paths": {
+      "/foo": {
+        "get": {}
+      },
+      "/foo/{foo_id}": {
+        "post": {}
+      }
     }
   }
-}
-JSON
+  JSON
     metaschema_uri => 'https://example.com/my_custom_metaschema',
   );
 
